<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\EventDelegate\Actions\AssociateToEvent;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Route;

class AttendingEventMiddlewareTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function cannot_view_event_if_not_attending(): void
    {
        $delegate = factory(Delegate::class)->create();
        $this->actingAsDelegate($delegate);
        $event = factory(Event::class)->state('published')->create();

        $this->get(route('test.event.route', $event))->assertStatus(401);
    }

    /** @test */
    public function can_view_event_if_attending(): void
    {
        $delegate = factory(Delegate::class)->create();
        $this->actingAsDelegate($delegate);
        $event = factory(Event::class)->state('published')->create();

        (new AssociateToEvent)->execute($event, [$delegate->id]);

        $this->get(route('test.event.route', $event))->assertStatus(200);
    }

    public function setUp(): void
    {
        parent::setUp();

        Route::get(
            'intest/{event}',
            function (Event $event) {
                return $event;
            }
        )->name('test.event.route')
            ->middleware(['web', 'requires-invite']);
    }
}
