<?php

namespace EventPortal\Tests\Unit\EventDelegate\Actions;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\EventDelegate\Actions\AssociateToEvent;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AssociateToEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function associate_delegates_to_event()
    {
        $event = factory(Event::class)->create();
        [$delegateA, $delegateB, $delegateC] = factory(Delegate::class, 3)->create();

        (new AssociateToEvent)->execute($event, [
            $delegateA->id,
            $delegateC->id,
        ]);

        $this->assertEventHasDelegates($event, [$delegateA, $delegateC]);
        $this->assertEventMissingDelegate($event, $delegateB);
    }

    /** @test **/
    public function does_not_associate_more_than_once()
    {
        $event = factory(Event::class)->create();
        $delegate = factory(Delegate::class)->create();

        (new AssociateToEvent)->execute($event, [$delegate->id]);
        (new AssociateToEvent)->execute($event, [$delegate->id]);

        $this->assertCount(1, EventDelegate::all());
    }
}
