<?php

namespace EventPortal\Tests\Unit\EventSpeaker\Actions;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\EventSpeaker\Actions\AssociateToEvent;
use EventPortal\Domain\EventSpeaker\Actions\DisassociateFromEvent;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class DisassociateFromEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function dissasociate_speakers_from_event()
    {
        $event = factory(Event::class)->create();
        [$speakerA, $speakerB, $speakerC] = factory(Speaker::class, 3)->create();

        (new AssociateToEvent)->execute($event, [
            $speakerA->id,
            $speakerB->id,
            $speakerC->id,
        ]);

        (new DisassociateFromEvent)->execute($event, [
            $speakerA->id,
            $speakerC->id,
        ]);

        $this->assertEventMissingSpeakers($event, [$speakerA, $speakerC]);
        $this->assertEventHasSpeaker($event, $speakerB);
    }
}
